# snowprofile

Toolbox to read, write and browse snow profile data with python.

The full documentation could be generated by running `make html` or `make pdf` inside the `doc` folder of this repository. The genrated documentation will be placed inside the `doc/build` folder.
